@@ -2,6 +2,7 @@
 from django.conf.urls import patterns, url
 
 from user_media.views import (
+    AJAXImageCropView,
     AJAXMultipleImageUploadView,
     AJAXSingleImageUploadView,
     CreateImageView,
@@ -21,6 +22,9 @@ urlpatterns = patterns(
     url(r'^image/(?P<pk>\d+)/$',
         UpdateImageView.as_view(),
         name='user_media_image_edit'),
+    url(r'^image/(?P<pk>\d+)/crop/$',
+        AJAXImageCropView.as_view(),
+        name='user_media_image_crop'),
     url(r'^image/(?P<pk>\d+)/delete/$',
         DeleteImageView.as_view(),
         name='user_media_image_delete'),
